# Copyright 2020 Peter Sobot
"""Unpack and repack Apple Keyote files."""
__author__ = "Peter Sobot"

import keynote_parser.macos_app_version

__major_version__ = 1
__patch_version__ = 1
__supported_keynote_version__ = keynote_parser.macos_app_version.MacOSAppVersion(
    "10.1", "6913", "1A148"
)
__version_tuple__ = (
    __major_version__,
    __supported_keynote_version__.major,
    __supported_keynote_version__.minor,
    __patch_version__,
)
__version__ = ".".join([str(x) for x in __version_tuple__])

__email__ = "github@petersobot.com"
__description__ = 'A tool for manipulating Apple Keynote presentation files.'
__url__ = "https://github.com/psobot/keynote-parser"
__new_issue_url__ = "https://github.com/psobot/keynote-parser/issues/new"
__command_line_invocation__ = False



from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSTArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSDArchives_sos_pb2 as TSDArchives__sos__pb2
from . import TSSArchives_sos_pb2 as TSSArchives__sos__pb2
from . import TSTStylePropertyArchiving_pb2 as TSTStylePropertyArchiving__pb2
from . import TSWPArchives_sos_pb2 as TSWPArchives__sos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSTArchives_sos.proto',
  package='TST',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x15TSTArchives_sos.proto\x12\x03TST\x1a\x15TSDArchives_sos.proto\x1a\x15TSSArchives_sos.proto\x1a\x1fTSTStylePropertyArchiving.proto\x1a\x16TSWPArchives_sos.proto\"t\n#SpecSetTableStrokePresetListArchive\x12>\n\x18table_stroke_preset_list\x18\x01 \x01(\x0b\x32\x1c.TST.StrokePresetListArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"w\n SpecTableStrokePresetListArchive\x12S\n!spec_set_table_stroke_preset_list\x18\x01 \x01(\x0b\x32(.TST.SpecSetTableStrokePresetListArchive\"\x8a\x03\n&TableCellStylePropertyChangeSetArchive\x12\'\n\ttext_wrap\x18\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1b\n\x13text_wrap_undefined\x18\x02 \x01(\x08\x12%\n\x04type\x18\x03 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x16\n\x0etype_undefined\x18\x04 \x01(\x08\x12\"\n\x04\x66ill\x18\x05 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x16\n\x0e\x66ill_undefined\x18\x06 \x01(\x08\x12\x33\n\x12vertical_alignment\x18\x07 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12$\n\x1cvertical_alignment_undefined\x18\x08 \x01(\x08\x12)\n\x07padding\x18\t \x01(\x0b\x32\x18.TSWP.SpecPaddingArchive\x12\x19\n\x11padding_undefined\x18\n \x01(\x08\"\xe0+\n\"TableStylePropertyChangeSetArchive\x12)\n\x0b\x61uto_resize\x18\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1d\n\x15\x61uto_resize_undefined\x18\x02 \x01(\x08\x12)\n\x0b\x62\x61nded_rows\x18\x03 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1d\n\x15\x62\x61nded_rows_undefined\x18\x04 \x01(\x08\x12.\n\x10\x62\x61nded_cell_fill\x18\x05 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\"\n\x1a\x62\x61nded_cell_fill_undefined\x18\x06 \x01(\x08\x12\x36\n\x18\x62\x65haves_like_spreadsheet\x18\x07 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"behaves_like_spreadsheet_undefined\x18\x08 \x01(\x08\x12=\n\x1d\x62ody_horizontal_border_stroke\x18\t \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12/\n\'body_horizontal_border_stroke_undefined\x18\n \x01(\x08\x12;\n\x1b\x62ody_vertical_border_stroke\x18\x0b \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12-\n%body_vertical_border_stroke_undefined\x18\x0c \x01(\x08\x12\x36\n\x16\x62ody_horizontal_stroke\x18\r \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12(\n body_horizontal_stroke_undefined\x18\x0e \x01(\x08\x12\x34\n\x14\x62ody_vertical_stroke\x18\x0f \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12&\n\x1e\x62ody_vertical_stroke_undefined\x18\x10 \x01(\x08\x12;\n\x1bheader_column_border_stroke\x18\x11 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12-\n%header_column_border_stroke_undefined\x18\x12 \x01(\x08\x12=\n\x1dheader_column_vertical_stroke\x18\x13 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12/\n\'header_column_vertical_stroke_undefined\x18\x14 \x01(\x08\x12?\n\x1fheader_column_horizontal_stroke\x18\x15 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x31\n)header_column_horizontal_stroke_undefined\x18\x16 \x01(\x08\x12>\n\x1eheader_column_separator_stroke\x18\x17 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x30\n(header_column_separator_stroke_undefined\x18\x18 \x01(\x08\x12\x38\n\x18header_row_border_stroke\x18\x19 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12*\n\"header_row_border_stroke_undefined\x18\x1a \x01(\x08\x12<\n\x1cheader_row_horizontal_stroke\x18\x1b \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12.\n&header_row_horizontal_stroke_undefined\x18\x1c \x01(\x08\x12:\n\x1aheader_row_vertical_stroke\x18\x1d \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$header_row_vertical_stroke_undefined\x18\x1e \x01(\x08\x12;\n\x1bheader_row_separator_stroke\x18\x1f \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12-\n%header_row_separator_stroke_undefined\x18  \x01(\x08\x12\x38\n\x18\x66ooter_row_border_stroke\x18! \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12*\n\"footer_row_border_stroke_undefined\x18\" \x01(\x08\x12<\n\x1c\x66ooter_row_horizontal_stroke\x18# \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12.\n&footer_row_horizontal_stroke_undefined\x18$ \x01(\x08\x12:\n\x1a\x66ooter_row_vertical_stroke\x18% \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$footer_row_vertical_stroke_undefined\x18& \x01(\x08\x12;\n\x1b\x66ooter_row_separator_stroke\x18\' \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12-\n%footer_row_separator_stroke_undefined\x18( \x01(\x08\x12H\n\x19stroke_preset_list_object\x18) \x01(\x0b\x32%.TST.SpecTableStrokePresetListArchive\x12+\n#stroke_preset_list_object_undefined\x18* \x01(\x08\x12\x36\n\x18vertical_strokes_visible\x18+ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"vertical_strokes_visible_undefined\x18, \x01(\x08\x12\x38\n\x1ahorizontal_strokes_visible\x18- \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n$horizontal_strokes_visible_undefined\x18. \x01(\x08\x12\x34\n\x16header_row_sep_visible\x18/ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n header_row_sep_visible_undefined\x18\x30 \x01(\x08\x12:\n\x1cheader_row_verticals_visible\x18\x31 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12.\n&header_row_verticals_visible_undefined\x18\x32 \x01(\x08\x12\x34\n\x16header_col_sep_visible\x18\x33 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n header_col_sep_visible_undefined\x18\x34 \x01(\x08\x12<\n\x1eheader_col_horizontals_visible\x18\x35 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x30\n(header_col_horizontals_visible_undefined\x18\x36 \x01(\x08\x12\x30\n\x12\x66ooter_sep_visible\x18\x37 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12$\n\x1c\x66ooter_sep_visible_undefined\x18\x38 \x01(\x08\x12\x36\n\x18\x66ooter_verticals_visible\x18\x39 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"footer_verticals_visible_undefined\x18: \x01(\x08\x12\x34\n\x16\x62order_strokes_visible\x18; \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n border_strokes_visible_undefined\x18< \x01(\x08\x12\x32\n\x12master_font_family\x18= \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12$\n\x1cmaster_font_family_undefined\x18> \x01(\x08\x12\x32\n\x11writing_direction\x18? \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1bwriting_direction_undefined\x18@ \x01(\x08\x12:\n\x1a\x63\x61tegory_level1_top_stroke\x18\x41 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$category_level1_top_stroke_undefined\x18\x42 \x01(\x08\x12:\n\x1a\x63\x61tegory_level2_top_stroke\x18\x43 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$category_level2_top_stroke_undefined\x18\x44 \x01(\x08\x12:\n\x1a\x63\x61tegory_level3_top_stroke\x18\x45 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$category_level3_top_stroke_undefined\x18\x46 \x01(\x08\x12:\n\x1a\x63\x61tegory_level4_top_stroke\x18G \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$category_level4_top_stroke_undefined\x18H \x01(\x08\x12:\n\x1a\x63\x61tegory_level5_top_stroke\x18I \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$category_level5_top_stroke_undefined\x18J \x01(\x08\x12\x46\n&category_level1_label_separator_stroke\x18K \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x38\n0category_level1_label_separator_stroke_undefined\x18L \x01(\x08\x12\x46\n&category_level2_label_separator_stroke\x18M \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x38\n0category_level2_label_separator_stroke_undefined\x18N \x01(\x08\x12\x46\n&category_level3_label_separator_stroke\x18O \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x38\n0category_level3_label_separator_stroke_undefined\x18P \x01(\x08\x12\x46\n&category_level4_label_separator_stroke\x18Q \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x38\n0category_level4_label_separator_stroke_undefined\x18R \x01(\x08\x12\x46\n&category_level5_label_separator_stroke\x18S \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x38\n0category_level5_label_separator_stroke_undefined\x18T \x01(\x08\x12=\n\x1d\x63\x61tegory_level1_bottom_stroke\x18U \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12/\n\'category_level1_bottom_stroke_undefined\x18V \x01(\x08\x12=\n\x1d\x63\x61tegory_level2_bottom_stroke\x18W \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12/\n\'category_level2_bottom_stroke_undefined\x18X \x01(\x08\x12=\n\x1d\x63\x61tegory_level3_bottom_stroke\x18Y \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12/\n\'category_level3_bottom_stroke_undefined\x18Z \x01(\x08\x12=\n\x1d\x63\x61tegory_level4_bottom_stroke\x18[ \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12/\n\'category_level4_bottom_stroke_undefined\x18\\ \x01(\x08\x12=\n\x1d\x63\x61tegory_level5_bottom_stroke\x18] \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12/\n\'category_level5_bottom_stroke_undefined\x18^ \x01(\x08\x12?\n\x1f\x63\x61tegory_level1_interior_stroke\x18_ \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x31\n)category_level1_interior_stroke_undefined\x18` \x01(\x08\x12?\n\x1f\x63\x61tegory_level2_interior_stroke\x18\x61 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x31\n)category_level2_interior_stroke_undefined\x18\x62 \x01(\x08\x12?\n\x1f\x63\x61tegory_level3_interior_stroke\x18\x63 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x31\n)category_level3_interior_stroke_undefined\x18\x64 \x01(\x08\x12?\n\x1f\x63\x61tegory_level4_interior_stroke\x18\x65 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x31\n)category_level4_interior_stroke_undefined\x18\x66 \x01(\x08\x12?\n\x1f\x63\x61tegory_level5_interior_stroke\x18g \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x31\n)category_level5_interior_stroke_undefined\x18h \x01(\x08')
  ,
  dependencies=[TSDArchives__sos__pb2.DESCRIPTOR,TSSArchives__sos__pb2.DESCRIPTOR,TSTStylePropertyArchiving__pb2.DESCRIPTOR,TSWPArchives__sos__pb2.DESCRIPTOR,])




_SPECSETTABLESTROKEPRESETLISTARCHIVE = _descriptor.Descriptor(
  name='SpecSetTableStrokePresetListArchive',
  full_name='TST.SpecSetTableStrokePresetListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_stroke_preset_list', full_name='TST.SpecSetTableStrokePresetListArchive.table_stroke_preset_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TST.SpecSetTableStrokePresetListArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=249,
)


_SPECTABLESTROKEPRESETLISTARCHIVE = _descriptor.Descriptor(
  name='SpecTableStrokePresetListArchive',
  full_name='TST.SpecTableStrokePresetListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_table_stroke_preset_list', full_name='TST.SpecTableStrokePresetListArchive.spec_set_table_stroke_preset_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=370,
)


_TABLECELLSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='TableCellStylePropertyChangeSetArchive',
  full_name='TST.TableCellStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_wrap', full_name='TST.TableCellStylePropertyChangeSetArchive.text_wrap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_wrap_undefined', full_name='TST.TableCellStylePropertyChangeSetArchive.text_wrap_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TST.TableCellStylePropertyChangeSetArchive.type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_undefined', full_name='TST.TableCellStylePropertyChangeSetArchive.type_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill', full_name='TST.TableCellStylePropertyChangeSetArchive.fill', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_undefined', full_name='TST.TableCellStylePropertyChangeSetArchive.fill_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment', full_name='TST.TableCellStylePropertyChangeSetArchive.vertical_alignment', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment_undefined', full_name='TST.TableCellStylePropertyChangeSetArchive.vertical_alignment_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='TST.TableCellStylePropertyChangeSetArchive.padding', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding_undefined', full_name='TST.TableCellStylePropertyChangeSetArchive.padding_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=767,
)


_TABLESTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='TableStylePropertyChangeSetArchive',
  full_name='TST.TableStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='auto_resize', full_name='TST.TableStylePropertyChangeSetArchive.auto_resize', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_resize_undefined', full_name='TST.TableStylePropertyChangeSetArchive.auto_resize_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='banded_rows', full_name='TST.TableStylePropertyChangeSetArchive.banded_rows', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='banded_rows_undefined', full_name='TST.TableStylePropertyChangeSetArchive.banded_rows_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='banded_cell_fill', full_name='TST.TableStylePropertyChangeSetArchive.banded_cell_fill', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='banded_cell_fill_undefined', full_name='TST.TableStylePropertyChangeSetArchive.banded_cell_fill_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='behaves_like_spreadsheet', full_name='TST.TableStylePropertyChangeSetArchive.behaves_like_spreadsheet', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='behaves_like_spreadsheet_undefined', full_name='TST.TableStylePropertyChangeSetArchive.behaves_like_spreadsheet_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_horizontal_border_stroke', full_name='TST.TableStylePropertyChangeSetArchive.body_horizontal_border_stroke', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_horizontal_border_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.body_horizontal_border_stroke_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_vertical_border_stroke', full_name='TST.TableStylePropertyChangeSetArchive.body_vertical_border_stroke', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_vertical_border_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.body_vertical_border_stroke_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_horizontal_stroke', full_name='TST.TableStylePropertyChangeSetArchive.body_horizontal_stroke', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_horizontal_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.body_horizontal_stroke_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_vertical_stroke', full_name='TST.TableStylePropertyChangeSetArchive.body_vertical_stroke', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_vertical_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.body_vertical_stroke_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_border_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_column_border_stroke', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_border_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_column_border_stroke_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_vertical_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_column_vertical_stroke', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_vertical_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_column_vertical_stroke_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_horizontal_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_column_horizontal_stroke', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_horizontal_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_column_horizontal_stroke_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_column_separator_stroke', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_column_separator_stroke_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_border_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_row_border_stroke', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_border_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_row_border_stroke_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_horizontal_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_row_horizontal_stroke', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_horizontal_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_row_horizontal_stroke_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_vertical_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_row_vertical_stroke', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_vertical_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_row_vertical_stroke_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.header_row_separator_stroke', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_row_separator_stroke_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_border_stroke', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_border_stroke', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_border_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_border_stroke_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_horizontal_stroke', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_horizontal_stroke', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_horizontal_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_horizontal_stroke_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_vertical_stroke', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_vertical_stroke', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_vertical_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_vertical_stroke_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_separator_stroke', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.footer_row_separator_stroke_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_preset_list_object', full_name='TST.TableStylePropertyChangeSetArchive.stroke_preset_list_object', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_preset_list_object_undefined', full_name='TST.TableStylePropertyChangeSetArchive.stroke_preset_list_object_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_strokes_visible', full_name='TST.TableStylePropertyChangeSetArchive.vertical_strokes_visible', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_strokes_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.vertical_strokes_visible_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_strokes_visible', full_name='TST.TableStylePropertyChangeSetArchive.horizontal_strokes_visible', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_strokes_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.horizontal_strokes_visible_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_sep_visible', full_name='TST.TableStylePropertyChangeSetArchive.header_row_sep_visible', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_sep_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_row_sep_visible_undefined', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_verticals_visible', full_name='TST.TableStylePropertyChangeSetArchive.header_row_verticals_visible', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_verticals_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_row_verticals_visible_undefined', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_col_sep_visible', full_name='TST.TableStylePropertyChangeSetArchive.header_col_sep_visible', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_col_sep_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_col_sep_visible_undefined', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_col_horizontals_visible', full_name='TST.TableStylePropertyChangeSetArchive.header_col_horizontals_visible', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_col_horizontals_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.header_col_horizontals_visible_undefined', index=53,
      number=54, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_sep_visible', full_name='TST.TableStylePropertyChangeSetArchive.footer_sep_visible', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_sep_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.footer_sep_visible_undefined', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_verticals_visible', full_name='TST.TableStylePropertyChangeSetArchive.footer_verticals_visible', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_verticals_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.footer_verticals_visible_undefined', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='border_strokes_visible', full_name='TST.TableStylePropertyChangeSetArchive.border_strokes_visible', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='border_strokes_visible_undefined', full_name='TST.TableStylePropertyChangeSetArchive.border_strokes_visible_undefined', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_font_family', full_name='TST.TableStylePropertyChangeSetArchive.master_font_family', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_font_family_undefined', full_name='TST.TableStylePropertyChangeSetArchive.master_font_family_undefined', index=61,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TST.TableStylePropertyChangeSetArchive.writing_direction', index=62,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction_undefined', full_name='TST.TableStylePropertyChangeSetArchive.writing_direction_undefined', index=63,
      number=64, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_top_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_top_stroke', index=64,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_top_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_top_stroke_undefined', index=65,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_top_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_top_stroke', index=66,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_top_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_top_stroke_undefined', index=67,
      number=68, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_top_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_top_stroke', index=68,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_top_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_top_stroke_undefined', index=69,
      number=70, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_top_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_top_stroke', index=70,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_top_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_top_stroke_undefined', index=71,
      number=72, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_top_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_top_stroke', index=72,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_top_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_top_stroke_undefined', index=73,
      number=74, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_label_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_label_separator_stroke', index=74,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_label_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_label_separator_stroke_undefined', index=75,
      number=76, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_label_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_label_separator_stroke', index=76,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_label_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_label_separator_stroke_undefined', index=77,
      number=78, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_label_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_label_separator_stroke', index=78,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_label_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_label_separator_stroke_undefined', index=79,
      number=80, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_label_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_label_separator_stroke', index=80,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_label_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_label_separator_stroke_undefined', index=81,
      number=82, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_label_separator_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_label_separator_stroke', index=82,
      number=83, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_label_separator_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_label_separator_stroke_undefined', index=83,
      number=84, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_bottom_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_bottom_stroke', index=84,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_bottom_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_bottom_stroke_undefined', index=85,
      number=86, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_bottom_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_bottom_stroke', index=86,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_bottom_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_bottom_stroke_undefined', index=87,
      number=88, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_bottom_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_bottom_stroke', index=88,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_bottom_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_bottom_stroke_undefined', index=89,
      number=90, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_bottom_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_bottom_stroke', index=90,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_bottom_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_bottom_stroke_undefined', index=91,
      number=92, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_bottom_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_bottom_stroke', index=92,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_bottom_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_bottom_stroke_undefined', index=93,
      number=94, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_interior_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_interior_stroke', index=94,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_interior_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level1_interior_stroke_undefined', index=95,
      number=96, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_interior_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_interior_stroke', index=96,
      number=97, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_interior_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level2_interior_stroke_undefined', index=97,
      number=98, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_interior_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_interior_stroke', index=98,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_interior_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level3_interior_stroke_undefined', index=99,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_interior_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_interior_stroke', index=100,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_interior_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level4_interior_stroke_undefined', index=101,
      number=102, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_interior_stroke', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_interior_stroke', index=102,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_interior_stroke_undefined', full_name='TST.TableStylePropertyChangeSetArchive.category_level5_interior_stroke_undefined', index=103,
      number=104, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=6370,
)

_SPECSETTABLESTROKEPRESETLISTARCHIVE.fields_by_name['table_stroke_preset_list'].message_type = TSTStylePropertyArchiving__pb2._STROKEPRESETLISTARCHIVE
_SPECTABLESTROKEPRESETLISTARCHIVE.fields_by_name['spec_set_table_stroke_preset_list'].message_type = _SPECSETTABLESTROKEPRESETLISTARCHIVE
_TABLECELLSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['text_wrap'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLECELLSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_TABLECELLSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_TABLECELLSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['vertical_alignment'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_TABLECELLSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['padding'].message_type = TSWPArchives__sos__pb2._SPECPADDINGARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['auto_resize'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['banded_rows'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['banded_cell_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['behaves_like_spreadsheet'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['body_horizontal_border_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['body_vertical_border_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['body_horizontal_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['body_vertical_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_column_border_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_column_vertical_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_column_horizontal_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_column_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_row_border_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_row_horizontal_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_row_vertical_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_row_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['footer_row_border_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['footer_row_horizontal_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['footer_row_vertical_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['footer_row_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stroke_preset_list_object'].message_type = _SPECTABLESTROKEPRESETLISTARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['vertical_strokes_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['horizontal_strokes_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_row_sep_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_row_verticals_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_col_sep_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['header_col_horizontals_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['footer_sep_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['footer_verticals_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['border_strokes_visible'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['master_font_family'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['writing_direction'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level1_top_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level2_top_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level3_top_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level4_top_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level5_top_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level1_label_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level2_label_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level3_label_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level4_label_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level5_label_separator_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level1_bottom_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level2_bottom_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level3_bottom_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level4_bottom_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level5_bottom_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level1_interior_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level2_interior_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level3_interior_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level4_interior_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_TABLESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_level5_interior_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetTableStrokePresetListArchive'] = _SPECSETTABLESTROKEPRESETLISTARCHIVE
DESCRIPTOR.message_types_by_name['SpecTableStrokePresetListArchive'] = _SPECTABLESTROKEPRESETLISTARCHIVE
DESCRIPTOR.message_types_by_name['TableCellStylePropertyChangeSetArchive'] = _TABLECELLSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['TableStylePropertyChangeSetArchive'] = _TABLESTYLEPROPERTYCHANGESETARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpecSetTableStrokePresetListArchive = _reflection.GeneratedProtocolMessageType('SpecSetTableStrokePresetListArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETTABLESTROKEPRESETLISTARCHIVE,
  __module__ = 'TSTArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TST.SpecSetTableStrokePresetListArchive)
  ))
_sym_db.RegisterMessage(SpecSetTableStrokePresetListArchive)

SpecTableStrokePresetListArchive = _reflection.GeneratedProtocolMessageType('SpecTableStrokePresetListArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECTABLESTROKEPRESETLISTARCHIVE,
  __module__ = 'TSTArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TST.SpecTableStrokePresetListArchive)
  ))
_sym_db.RegisterMessage(SpecTableStrokePresetListArchive)

TableCellStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('TableCellStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLECELLSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSTArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableCellStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(TableCellStylePropertyChangeSetArchive)

TableStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('TableStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLESTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSTArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(TableStylePropertyChangeSetArchive)


# @@protoc_insertion_point(module_scope)
